From cb9fdd50aeafcfcb7caca77406cb70c62c375596 Mon Sep 17 00:00:00 2001
From: Vallimaharajan <vallimaharajan.gs@zohocorp.com>
Date: Wed, 13 Nov 2024 20:18:36 +0530
Subject: [PATCH] Set aggregate values to NULL when run condition fails in
 WINDOWAGG_PASSTHROUGH_STRICT mode

---
 src/backend/executor/nodeWindowAgg.c | 34 +++++++++++++---------------
 1 file changed, 16 insertions(+), 18 deletions(-)

diff --git a/src/backend/executor/nodeWindowAgg.c b/src/backend/executor/nodeWindowAgg.c
index 51a6708a39..839808fd58 100644
--- a/src/backend/executor/nodeWindowAgg.c
+++ b/src/backend/executor/nodeWindowAgg.c
@@ -2353,6 +2353,22 @@ ExecWindowAgg(PlanState *pstate)
 				 */
 				if (winstate->use_pass_through)
 				{
+					/*
+					 * we'd better NULLify the aggregate results for pass-through
+					 * mode. In this mode we no longer update these and this
+					 * avoids the old stale results lingering.  Some of these
+					 * might be byref types so we can't have them pointing to
+					 * free'd memory.  The planner insisted that quals used in the
+					 * runcondition are strict, so the top-level WindowAgg will
+					 * filter these NULLs out in the filter clause.
+					 */
+					numfuncs = winstate->numfuncs;
+					for (i = 0; i < numfuncs; i++)
+					{
+						econtext->ecxt_aggvalues[i] = (Datum) 0;
+						econtext->ecxt_aggnulls[i] = true;
+					}
+
 					/*
 					 * STRICT pass-through mode is required for the top window
 					 * when there is a PARTITION BY clause.  Otherwise we must
@@ -2367,24 +2383,6 @@ ExecWindowAgg(PlanState *pstate)
 					else
 					{
 						winstate->status = WINDOWAGG_PASSTHROUGH;
-
-						/*
-						 * If we're not the top-window, we'd better NULLify
-						 * the aggregate results.  In pass-through mode we no
-						 * longer update these and this avoids the old stale
-						 * results lingering.  Some of these might be byref
-						 * types so we can't have them pointing to free'd
-						 * memory.  The planner insisted that quals used in
-						 * the runcondition are strict, so the top-level
-						 * WindowAgg will filter these NULLs out in the filter
-						 * clause.
-						 */
-						numfuncs = winstate->numfuncs;
-						for (i = 0; i < numfuncs; i++)
-						{
-							econtext->ecxt_aggvalues[i] = (Datum) 0;
-							econtext->ecxt_aggnulls[i] = true;
-						}
 					}
 				}
 				else
-- 
2.34.1

